==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebKit/WebProcess/UserContent/SharedMemoryJSBuffer.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SharedMemoryJSBuffer.h"

#include <WebCore/ExceptionOr.h>
#include <WebCore/SharedMemory.h>
#include <wtf/text/ExternalStringImpl.h>

namespace WebKit {

Ref<SharedMemoryJSBuffer> SharedMemoryJSBuffer::create(Ref<WebCore::SharedMemory>&& data)
{
    return adoptRef(*new SharedMemoryJSBuffer(WTFMove(data)));
}

SharedMemoryJSBuffer::SharedMemoryJSBuffer(Ref<WebCore::SharedMemory>&& sharedMemory)
    : m_sharedMemory(WTFMove(sharedMemory))
{
}

WebCore::ExceptionOr<String> SharedMemoryJSBuffer::asUTF16String() const
{
    if (m_sharedMemory->size() % sizeof(char16_t))
        return WebCore::Exception { WebCore::ExceptionCode::RangeError };
    Ref<StringImpl> impl = ExternalStringImpl::create(spanReinterpretCast<const char16_t>(m_sharedMemory->span()), [protectedMemory = Ref { m_sharedMemory }] (auto...) mutable { });
    return String(WTFMove(impl));
}

String SharedMemoryJSBuffer::asLatin1String() const
{
    Ref<StringImpl> impl = ExternalStringImpl::create(spanReinterpretCast<const Latin1Character>(m_sharedMemory->span()), [protectedMemory = Ref { m_sharedMemory }] (auto...) mutable { });
    return String(WTFMove(impl));
}

}

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebKit/WebProcess/UserContent/SharedMemoryJSBuffer.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SharedMemoryJSBuffer.h"

#include <WebCore/ExceptionOr.h>
#include <WebCore/SharedMemory.h>
#include <wtf/text/ExternalStringImpl.h>

namespace WebKit {

Ref<SharedMemoryJSBuffer> SharedMemoryJSBuffer::create(Ref<WebCore::SharedMemory>&& data)
{
    return adoptRef(*new SharedMemoryJSBuffer(WTF::move(data)));
}

SharedMemoryJSBuffer::SharedMemoryJSBuffer(Ref<WebCore::SharedMemory>&& sharedMemory)
    : m_sharedMemory(WTF::move(sharedMemory))
{
}

WebCore::ExceptionOr<String> SharedMemoryJSBuffer::asUTF16String() const
{
    if (m_sharedMemory->size() % sizeof(char16_t))
        return WebCore::Exception { WebCore::ExceptionCode::RangeError };
    Ref<StringImpl> impl = ExternalStringImpl::create(spanReinterpretCast<const char16_t>(m_sharedMemory->span()), [protectedMemory = Ref { m_sharedMemory }] (auto...) mutable { });
    return String(WTF::move(impl));
}

String SharedMemoryJSBuffer::asLatin1String() const
{
    Ref<StringImpl> impl = ExternalStringImpl::create(spanReinterpretCast<const Latin1Character>(m_sharedMemory->span()), [protectedMemory = Ref { m_sharedMemory }] (auto...) mutable { });
    return String(WTF::move(impl));
}

}
